@@ -26,6 +26,7 @@ from suite_py.commands.qa import QA
 from suite_py.commands.release import Release
 from suite_py.commands.secret import Secret
 from suite_py.commands.status import Status
+from suite_py.commands.docker import Docker
 from suite_py.lib import logger
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
@@ -207,6 +208,23 @@ def cli_deploy(obj):
     Deploy(obj["project"], obj["config"], obj["tokens"]).run()
 
 
+@main.group("docker", help="Manage docker images")
+def docker():
+    pass
+
+
+@docker.command("release", help="Release new docker image")
+@click.pass_obj
+def cli_docker_release(obj):
+    Docker("release", obj["project"], obj["config"], obj["tokens"]).run()
+
+
+@docker.command("versions", help="List all available versions of specific image")
+@click.pass_obj
+def cli_docker_versions(obj):
+    Docker("versions", obj["project"], obj["config"], obj["tokens"]).run()
+
+
 @main.command("status", help="Current status of a project")
 @click.pass_obj
 def cli_status(obj):
